@@ -353,7 +353,7 @@ enum {
 	R_SYS_ARCH_JAVA = 0x10,
 	R_SYS_ARCH_MIPS = 0x20,
 	R_SYS_ARCH_SPARC = 0x40,
-	R_SYS_ARCH_CSR = 0x80,
+	R_SYS_ARCH_XAP = 0x80,
 	R_SYS_ARCH_MSIL = 0x100,
 	R_SYS_ARCH_OBJD = 0x200,
 	R_SYS_ARCH_BF = 0x400,
