@@ -3,12 +3,6 @@
 
 #include "r_version.h"
 
-#ifdef LIL_ENDIAN
-#undef LIL_ENDIAN
-#endif
-#define LIL_ENDIAN 1
-#define CPU_ENDIAN 0
-
 #define DEBUGGER 1
 
 #if __WIN32__ || __CYGWIN__ || MINGW32
@@ -23,15 +17,12 @@
 #define R2_DATDIR "/usr/share"
 #endif
 
-#define R2_VERSION "0.10.2"
+#define R2_VERSION "0.10.5"
 #define HAVE_LIB_MAGIC 1
 #define USE_LIB_MAGIC 0
 #ifndef HAVE_LIB_SSL
 #define HAVE_LIB_SSL 1
 #endif
-#ifndef HAVE_LIB_EWF
-#define HAVE_LIB_EWF @HAVE_LIB_EWF@
-#endif
 
 #define HAVE_FORK 1
 
